"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.watch = exports.compile = void 0;
const child_process_1 = require("child_process");
const path_1 = __importDefault(require("path"));
const chalk_1 = __importDefault(require("chalk"));
const chokidar_1 = __importDefault(require("chokidar"));
const debug = require('debug')('vite-plugin-rust:compiler');
function compileOne(crate, opt, sync) {
    // TODO: toggle this mode base on build profile
    let mode = '--dev';
    let exe = 'wasm-pack';
    if (process.platform == 'win32') {
        exe = 'wasm-pack.exe';
    }
    const args = ['build', mode, '--out-name', opt.outName, '--target', 'web'];
    debug('Running subprocess with command: ', exe, args.join(' '));
    if (sync) {
        let ps = child_process_1.spawnSync(exe, args, {
            shell: true,
            cwd: opt.path,
            encoding: 'utf-8',
            stdio: ['inherit', 'inherit', 'inherit'],
        });
        if (ps.status != 0) {
            throw chalk_1.default.red(`wasm-pack for crate ${crate} failed`);
        }
    }
    else {
        let ps = child_process_1.spawn(exe, args, {
            shell: true,
            cwd: opt.path,
            stdio: ['inherit', 'inherit', 'inherit'],
        });
        ps.on('close', code => {
            if (code != 0) {
                throw chalk_1.default.red(`wasm-pack for crate ${crate} failed`);
            }
        });
    }
}
function compile(cfg, crate, sync) {
    const { crates, wasmPack } = cfg;
    debug('Compile using wasm-pack at', wasmPack);
    for (let crate in crates) {
        let opt = crates[crate];
        compileOne(crate, opt, sync || false);
    }
}
exports.compile = compile;
function watch(cfg, cbk) {
    Object.entries(cfg.crates).forEach(([crateName, opt]) => {
        chokidar_1.default.watch([
            path_1.default.join(opt.path, '/src'),
            path_1.default.join(opt.path, 'Cargo.toml'),
        ], {
            ignoreInitial: true,
        }).on('all', (event, path) => {
            console.log('Crate', crateName, 'changed!', 'Event:', event, 'File:', path);
            cbk(crateName);
        });
    });
}
exports.watch = watch;
//# sourceMappingURL=compiler.js.map