"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeConfig = exports.PluginConfig = void 0;
const which_1 = __importDefault(require("which"));
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
class PluginConfig {
    constructor(wasmPack, crates, root) {
        this.wasmPack = wasmPack;
        this.crates = crates;
        this.root = root;
    }
    // given a local file absolute path, check if it's in one of our crates
    // if so, split it into crate and remaining path
    crateForFile(filePath) {
        for (let crate in this.crates) {
            let cratePath = this.crates[crate].path + path_1.default.sep + 'pkg';
            if (filePath.startsWith(cratePath)) {
                return [crate, filePath.substring(cratePath.length + 1)];
            }
        }
    }
    filePathForCrate(crate, filePath) {
        if (crate in this.crates) {
            let cratePath = this.crates[crate].path;
            return path_1.default.resolve(cratePath, 'pkg', filePath);
        }
    }
    // if the given relative file path is crate entry js file
    isEntryForCrate(crate, filePath) {
        if (crate in this.crates) {
            let outName = this.crates[crate].outName;
            return filePath == outName + '.js';
        }
        return false;
    }
}
exports.PluginConfig = PluginConfig;
function normalizeConfig(cfg, root) {
    let wasmPack = cfg.wasmPack;
    if (!wasmPack) {
        wasmPack = which_1.default.sync('wasm-pack', { nothrow: true }) || undefined;
        if (!wasmPack) {
            throw chalk_1.default.red('Cannot find wasm-pack in your PATH. Please make sure wasm-pack is installed');
        }
    }
    let newCrates = {};
    for (let crate in cfg.crates) {
        let opt = cfg.crates[crate];
        let newCrate;
        if (typeof opt == 'string') {
            newCrate = {
                path: path_1.default.resolve(root, opt),
                outName: nameForCrate(crate),
            };
        }
        else {
            newCrate = {
                path: path_1.default.resolve(root, opt.path),
                outName: opt.outName,
            };
        }
        newCrates[crate] = newCrate;
    }
    return new PluginConfig(wasmPack, newCrates, root);
}
exports.normalizeConfig = normalizeConfig;
function nameForCrate(crate) {
    return crate.replace(/-/g, '_').toLowerCase();
}
//# sourceMappingURL=config.js.map