"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const compiler_1 = require("./compiler");
const rustRollupPlugin_1 = require("./rustRollupPlugin");
const debug = require('debug')('vite-plugin-rust:index');
const URL_PREFIX = '/@rust/';
function urlForCrate(crate, ...pathes) {
    let tail = pathes.map(p => p.replace(/\\/g, '/')).join('/');
    return `${URL_PREFIX}${crate}/${tail}`;
}
module.exports = (config) => {
    let root = process.cwd();
    let cfg = config_1.normalizeConfig(config, root);
    debug('vite-plugin-rust config', cfg);
    // Do initial compile in dev mode
    // wasm-pack compile in build is done in rollup plugin
    compiler_1.compile(cfg, '', true);
    // TODO: only watch in dev mode
    compiler_1.watch(cfg, crate => {
        compiler_1.compile(cfg, crate);
    });
    return {
        resolvers: [{
                alias(id) {
                    let parts = id.split('/', 2);
                    if (parts.length >= 1) {
                        let [crate, filePath] = parts;
                        if (crate in cfg.crates) {
                            if (!filePath) {
                                filePath = cfg.crates[crate].outName + '.js';
                            }
                            return urlForCrate(crate, filePath);
                        }
                    }
                },
                requestToFile(publicPath, root) {
                    if (publicPath.startsWith(URL_PREFIX)) {
                        let seg = publicPath.substring(URL_PREFIX.length);
                        let [crate, filePath] = seg.split('/', 2);
                        return cfg.filePathForCrate(crate, filePath);
                    }
                },
                fileToRequest(filePath, root) {
                    let crateInfo = cfg.crateForFile(filePath);
                    if (crateInfo) {
                        return urlForCrate(...crateInfo);
                    }
                },
            }],
        rollupInputOptions: {
            plugins: [
                rustRollupPlugin_1.createRustRollupPlugin(cfg),
            ]
        }
    };
};
//# sourceMappingURL=index.js.map